<?php

declare(strict_types=1);

namespace Dedi\SyliusBannerPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * @ORM\Entity
 * @ORM\Table(name="dedi_banner_alert_message")
 */
class AlertMessage implements AlertMessageInterface
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     * @ORM\Column(type="integer", nullable=false, name="id")
     */
    private ?int $id;

    /** @ORM\Column(name="enabled", type="boolean", nullable=false) */
    private bool $enabled;

    /** @ORM\Column(name="start_date_time", type="datetime_immutable", nullable=true) */
    private ?\DateTimeImmutable $startDateTime;

    /**
     * @ORM\Column(name="end_date_time", type="datetime_immutable", nullable=true)
     * @Assert\Expression(
     *     expression="value == null || value >= this.getStartDateTime()",
     *     groups={"default", "sylius"},
     *     message="dedi_banner.alert_message.end_date_can_t_be_before_start_date"
     * )
     */
    private ?\DateTimeImmutable $endDateTime;

    /** @ORM\Column(name="message", type="string", nullable=false) */
    private ?string $message;

    /** @ORM\Column(name="link", type="string", nullable=true) */
    private ?string $link;

    /** @ORM\Column(name="link_label", type="string", nullable=true) */
    private ?string $linkLabel;

    /** @ORM\Column(name="is_basket_alert", type="boolean") */
    private bool $isBasketAlert;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function setId($id): AlertMessage
    {
        $this->id = $id;

        return $this;
    }

    public function isEnabled(): bool
    {
        return $this->enabled;
    }

    public function setEnabled(bool $enabled): AlertMessageInterface
    {
        $this->enabled = $enabled;

        return $this;
    }

    public function getStartDateTime(): ?\DateTimeImmutable
    {
        return $this->startDateTime;
    }

    public function setStartDateTime(?\DateTimeImmutable $startDateTime): AlertMessageInterface
    {
        $this->startDateTime = $startDateTime;

        return $this;
    }

    public function getEndDateTime(): ?\DateTimeImmutable
    {
        return $this->endDateTime;
    }

    public function setEndDateTime(?\DateTimeImmutable $endDateTime): AlertMessageInterface
    {
        $this->endDateTime = $endDateTime;

        return $this;
    }

    public function getMessage(): ?string
    {
        return $this->message;
    }

    public function setMessage(string $message): AlertMessageInterface
    {
        $this->message = $message;

        return $this;
    }

    public function getLink(): ?string
    {
        return $this->link;
    }

    public function setLink(string $link): AlertMessageInterface
    {
        $this->link = $link;

        return $this;
    }

    public function getLinkLabel(): ?string
    {
        return $this->linkLabel;
    }

    public function setLinkLabel(string $linkLabel): AlertMessageInterface
    {
        $this->linkLabel = $linkLabel;

        return $this;
    }

    public function getIsBasketAlert(): bool
    {
        return $this->isBasketAlert;
    }

    public function setIsBasketAlert(bool $isBasketAlert): AlertMessage
    {
        $this->isBasketAlert = $isBasketAlert;
        return $this;
    }
}
