<?php

namespace Dedi\SyliusBannerPlugin\Form\Type;

use Sylius\Bundle\ResourceBundle\Form\Type\AbstractResourceType;
use Sylius\Bundle\ResourceBundle\Form\Type\ResourceTranslationsType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\DateTimeType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints\NotNull;
use Symfony\Component\Validator\Constraints\Url;


final class AlertMessageType extends AbstractResourceType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('enabled', CheckboxType::class, [
                'label' => 'sylius.ui.enabled',
                'required' => false,
            ])
            ->add('startDateTime', DateTimeType::class, [
                'label' => 'dedi_banner.ui.start_datetime',
                'required' => false,
                'input' => 'datetime_immutable',
                'widget' => 'single_text',
            ])
            ->add('endDateTime', DateTimeType::class, [
                'label' => 'dedi_banner.ui.end_datetime',
                'required' => false,
                'input' => 'datetime_immutable',
                'widget' => 'single_text',
            ])
            ->add('message', TextType::class, [
                'label' => 'sylius.ui.message',
                'constraints' => [
                    new NotNull(['groups' => ['default', 'sylius']]),
                ],
            ])
            ->add('link', TextType::class, [
                'label' => 'dedi_banner.ui.link',
                'required' => false,
                'constraints' => [
                    new Url(['groups' => ['default', 'sylius']]),
                ],
            ])
            ->add('linkLabel', TextType::class, [
                'label' => 'dedi_banner.ui.link_label',
                'required' => false,
            ])
        ;
    }

    public function getBlockPrefix(): string
    {
        return 'dedi_banner_alert_message';
    }
}